@@ -1,7 +1,7 @@
 import time
 
 from notecoin.database.base import Base, BaseTable, session
-from sqlalchemy import BIGINT, Column, Float, String
+from sqlalchemy import BIGINT, INTEGER, Column, Float, String
 
 
 class OkexSocketPublicTickers(Base, BaseTable):
@@ -78,3 +78,16 @@ class OkexWebsocketChannels(Base, BaseTable):
         except Exception as e:
             session.rollback()
             return {"delete error": str(e)}
+
+
+class OkexWebsocketResponse(Base, BaseTable):
+    __tablename__ = 'okex_websocket_response'
+    id = Column(INTEGER(), comment='id', autoincrement=True, primary_key=True)
+    channel = Column(String(), comment='channel')
+    response = Column(String(), comment='response')
+    updateTime = Column(BIGINT(), comment='updateTime')
+
+    def __init__(self, *args, **kwargs):
+        self.channel = kwargs.get("channel")
+        self.response = kwargs.get("response")
+        self.updateTime = int(time.time() * 1000)
